RoundingMode
------------

- enum :cpp:enum:`bitwuzla::RoundingMode`
- :cpp:func:`std::ostream& bitwuzla::operator<< (std::ostream& out, RoundingMode rm)`
- :cpp:func:`std::string std::to_string(bitwuzla::RoundingMode rm)`

----

:code:`namespace bitwuzla {`

.. doxygenenum:: bitwuzla::RoundingMode
    :project: Bitwuzla_cpp

----

.. doxygenfunction:: bitwuzla::operator<<(std::ostream& out, RoundingMode rm)
    :project: Bitwuzla_cpp

:code:`}`

----

:code:`namespace std {`

.. doxygenfunction:: std::to_string(bitwuzla::RoundingMode rm)
    :project: Bitwuzla_cpp

:code:`}`
